This crate contains kube-rs compatible bindings for Kubernetes custom resources for the sriovnetwork.openshift.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
sriovnetwork.openshift.io/v1
OVSNetworkSriovIBNetworkSriovNetworkNodePolicySriovNetworkNodeStateSriovNetworkPoolConfigSriovNetworkSriovOperatorConfig